@@ -6,3 +6,5 @@ WIALON_ADMIN_ID = getenv("WIALON_ADMIN_ID")
 WIALON_TOKEN = getenv("WIALON_TOKEN")
 MERCHANT_AUTH_LOGIN_ID = getenv("MERCHANT_AUTH_LOGIN_ID")
 MERCHANT_AUTH_TRANSACTION_KEY = getenv("MERCHANT_AUTH_TRANSACTION_KEY")
+QB_CLIENT_ID = getenv("QB_CLIENT_ID")
+QB_CLIENT_SECRET = getenv("QB_CLIENT_ID")
